==> haskell-implicit-hie-cradle-0.5.0.1-184-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie-cradle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie-cradle
version:              0.5.0.1
visibility:           public
id:                   implicit-hie-cradle-0.5.0.1-J3a6bj5Lnow490wWhNiiGK
key:                  implicit-hie-cradle-0.5.0.1-J3a6bj5Lnow490wWhNiiGK
license:              BSD-3-Clause
copyright:            2023
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie-cradle#readme
synopsis:             Auto generate hie-bios cradles
description:          Auto generate a stack or cabal multi component cradles
category:             Development, Tools, Hie, HLS
abi:                  6ba79d49e4c1ac6b9dc3d5bfdbfa9b30
exposed:              True
exposed-modules:      Hie.Implicit.Cradle
hidden-modules:       Paths_implicit_hie_cradle
import-dirs:          /usr/lib/ghc-9.6.6/site-local/implicit-hie-cradle-0.5.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/implicit-hie-cradle-0.5.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/implicit-hie-cradle-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie-cradle
hs-libraries:         HSimplicit-hie-cradle-0.5.0.1-J3a6bj5Lnow490wWhNiiGK
depends:
    base-4.18.2.1 directory-1.3.8.5 extra-1.7.16-IkudFHstV64EKMSGT8IWWb
    filepath-1.4.300.1 hie-bios-0.12.0-FNEim36epU8Dn9Th1xNmRS
    implicit-hie-0.1.4.0-6gHANNr4w6g2WMvlW7rWZC process-1.6.19.0
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie-cradle/html/implicit-hie-cradle.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie-cradle/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-implicit-hie-cradle-0.5.0.1-186-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie-cradle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie-cradle
version:              0.5.0.1
visibility:           public
id:                   implicit-hie-cradle-0.5.0.1-1QjYA8bbAiKKbZSRHz2GWl
key:                  implicit-hie-cradle-0.5.0.1-1QjYA8bbAiKKbZSRHz2GWl
license:              BSD-3-Clause
copyright:            2023
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie-cradle#readme
synopsis:             Auto generate hie-bios cradles
description:          Auto generate a stack or cabal multi component cradles
category:             Development, Tools, Hie, HLS
abi:                  d2d905ff9f040a1080569a897ac669ad
exposed:              True
exposed-modules:      Hie.Implicit.Cradle
hidden-modules:       Paths_implicit_hie_cradle
import-dirs:          /usr/lib/ghc-9.6.6/site-local/implicit-hie-cradle-0.5.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/implicit-hie-cradle-0.5.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/implicit-hie-cradle-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie-cradle
hs-libraries:         HSimplicit-hie-cradle-0.5.0.1-1QjYA8bbAiKKbZSRHz2GWl
depends:
    base-4.18.2.1 directory-1.3.8.5 extra-1.7.16-1R70WzmZutyIjhcnCYje37
    filepath-1.4.300.1 hie-bios-0.12.0-D5SlUNhEiEdEEQ41lCtVRh
    implicit-hie-0.1.4.0-eJGhYMuT5820CAHOClIh1 process-1.6.19.0
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie-cradle/html/implicit-hie-cradle.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie-cradle/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
